scriptDir = 'scripts'
source(file.path(scriptDir, 'setup.R'))

params = fread(file.path(paramDir, 'analysis_params.csv'))
assayMetadata = fread(file.path(paramDir, 'assay_metadata.csv'))
measDrugExp = fread(file.path(dataDir, 'screen_conf_drug_exp.csv.gz'))
measScreenConf = fread(file.path(dataDir, 'screen_conf.csv.gz'))

########################################

measDrugExpSummary = measDrugExp[, .(n_results = .N),
                                 keyby = .(ingred_name, screen_id, measurement_result)]
measDrugExpSummary[, meas_result := paste0('n_', measurement_result)]

measDrugExpSummary = dcast(measDrugExpSummary, ingred_name + screen_id ~ meas_result,
                           value.var = 'n_results', fill = 0)

fwrite(measDrugExpSummary, file.path(resultDir, 'counts_ingred_screen_result.csv'))

########################################

dStatsTmp = getMeasDrugExpStats(measDrugExp, measScreenConf, params$min_persons_pos)

dStats = merge(assayMetadata[assay_type == 'screen',
                             .(screen_target, screen_id = assay_id)],
               dStatsTmp, by = 'screen_id')

dStats = merge(dStats, measDrugExpSummary, by = c('screen_id', 'ingred_name'))

dStatsAsh = getAshStats(dStats)
dStats = cbind(dStats, dStatsAsh)
setorder(dStats, screen_target, -PosteriorMean)

dStats[, `:=`(or_pm = exp(PosteriorMean),
              or_credint_lower = exp(credint_lower),
              or_credint_upper = exp(credint_upper))]

fwrite(dStats, file.path(resultDir, 'stats_pos_neg.csv'))

fwrite(dStats[, .SD[1:min(params$n_top, .N)], by = screen_target],
       file.path(resultDir, 'stats_pos_neg_top.csv'))

########################################

dStatsPosPosTmp = getMeasDrugExpStats(measDrugExp, measScreenConf,
                                      params$min_persons_pos,
                                      measResult2 = 'pos_pos')

dStatsPosPos = merge(assayMetadata[assay_type == 'screen',
                                   .(screen_target, screen_id = assay_id)],
                     dStatsPosPosTmp, by = 'screen_id')

dStatsPosPos = merge(dStatsPosPos, measDrugExpSummary,
                     by = c('screen_id', 'ingred_name'))

dStatsPosPosAsh = getAshStats(dStatsPosPos)
dStatsPosPos = cbind(dStatsPosPos, dStatsPosPosAsh)
setorder(dStatsPosPos, screen_target, -PosteriorMean)

dStatsPosPos[, `:=`(or_pm = exp(PosteriorMean),
                    or_credint_lower = exp(credint_lower),
                    or_credint_upper = exp(credint_upper))]

fwrite(dStatsPosPos, file.path(resultDir, 'stats_pos_pos.csv'))
